@@ -15,10 +15,10 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <config.h>
 #include <libxml++/libxml++.h>
 
 #include <cstdlib>
-#include <glibmm.h>
 #include <sstream>
 #include <stdexcept>
 
@@ -37,7 +37,9 @@ protected:
 
 int main()
 {
-  Glib::init();
+  // Set the global C and C++ locale to the user-configured locale,
+  // so we can use std::cout with UTF-8, via Glib::ustring, without exceptions.
+  std::locale::global(std::locale(""));
 
   {
     MySaxParser parser;
